package com.xunmei.system.mapper;

import java.util.List;

import com.xunmei.system.domain.SysNfcBind;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-15
 */
@Mapper
public interface SysNfcBindMapper extends BaseMapper<SysNfcBind> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysNfcBind selectSysNfcBindById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysNfcBind 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysNfcBind> selectSysNfcBindList(SysNfcBind sysNfcBind);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysNfcBind 【请填写功能名称】
     * @return 结果
     */
     int insertSysNfcBind(SysNfcBind sysNfcBind);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysNfcBind 【请填写功能名称】
     * @return 结果
     */
     int updateSysNfcBind(SysNfcBind sysNfcBind);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysNfcBindById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysNfcBindByIds(Long[] ids);
}
